import React, { useState, useEffect, useMemo } from 'react';
import { PageContainer } from '@ant-design/pro-components';
import { Card, Tabs } from 'antd';
import { useModel } from '@umijs/max';
import Banner from '@/components/Banner';
import { getBanners, deleteBanner, uploadBanner } from '@/services/ant-design-pro/api';
import { requestUpload } from '@/utils/upload';
import { bannerTypes } from '@/constant';

interface IItemImage {
  id: number;
  type: number;
  url: string;
}

const Page = () => {
  const { initialState } = useModel('@@initialState');
  const [dataList, setDataList] = useState<IItemImage[]>([]);

  const getBannerList = async () => {
    const result = await getBanners();
    setDataList(result.data);
  };

  useEffect(() => {
    getBannerList();
  }, []);

  /**
   * 上传图片
   * @param info 文件内容
   * @param type 轮播图类型
   */
  const handleFileUpload = async (fileInfo: any, params: { type: number; path: string }) => {
    const file = fileInfo.file.originFileObj;
    const fileName = fileInfo.file.name;
    const url = await requestUpload(file as Blob, fileName);
    await uploadBanner({ url, ...params });
    getBannerList();
  };

  /**
   * 删除图片
   * @param id 文件id
   */
  const handleDelImage = async (id: number) => {
    await deleteBanner(id);
    getBannerList();
  };

  const items = useMemo(() => {
    return bannerTypes.map((itemTab) => {
      const dataSource = dataList.filter((_item) => itemTab.type === _item.type);
      return {
        key: itemTab.type + '',
        label: itemTab.name,
        children: (
          <Banner
            key={itemTab.type}
            dataSource={dataSource}
            type={itemTab.type}
            onDelFile={handleDelImage}
            onChange={handleFileUpload}
          />
        ),
      };
    });
  }, [dataList]);

  return (
    <>
      <PageContainer>
        <Card
          style={{
            borderRadius: 8,
          }}
          bodyStyle={{
            backgroundImage:
              initialState?.settings?.navTheme === 'realDark'
                ? 'background-image: linear-gradient(75deg, #1A1B1F 0%, #191C1F 100%)'
                : 'background-image: linear-gradient(75deg, #FBFDFF 0%, #F5F7FF 100%)',
          }}
        >
          <Tabs type="card" defaultActiveKey="1" items={items} />
        </Card>
      </PageContainer>
    </>
  );
};

export default Page;
